@@ -3,6 +3,7 @@ sgr commands related to sharing and downloading images.
 """
 
 import sys
+from typing import Optional
 
 import click
 
@@ -20,7 +21,10 @@ from splitgraph.config.config import get_from_subsection
     help="Download all objects immediately instead of on checkout.",
 )
 @click.option(
-    "-f", "--overwrite-object-meta", help="Overwrite metadata for existing objects", is_flag=True,
+    "-f",
+    "--overwrite-object-meta",
+    help="Overwrite metadata for existing objects",
+    is_flag=True,
 )
 @click.option("-t", "--tags", help="Overwrite tags for pulled image/repo", is_flag=True)
 def pull_c(repository_or_image, download_all, overwrite_object_meta, tags):
@@ -48,7 +52,10 @@ def pull_c(repository_or_image, download_all, overwrite_object_meta, tags):
     is_flag=True,
 )
 @click.option(
-    "-f", "--overwrite-object-meta", help="Overwrite metadata for existing objects", is_flag=True,
+    "-f",
+    "--overwrite-object-meta",
+    help="Overwrite metadata for existing objects",
+    is_flag=True,
 )
 @click.option("-t", "--tags", help="Overwrite tags for pulled image/repo", is_flag=True)
 def clone_c(
@@ -88,7 +95,11 @@ def clone_c(
 @click.argument("repository_or_image", type=ImageType(default=None))
 @click.argument("remote_repository", required=False, type=RepositoryType())
 @click.option(
-    "-r", "--remote", help="Name of the remote engine", type=click.Choice(REMOTES), default=None,
+    "-r",
+    "--remote",
+    help="Name of the remote engine",
+    type=click.Choice(REMOTES),
+    default=None,
 )
 @click.option("-h", "--upload-handler", help="Upload handler", default="S3")
 @click.option(
@@ -213,6 +224,7 @@ def _make_push_target(repository, remote):
     from splitgraph.core.repository import Repository
     from splitgraph.engine import get_engine
 
+    namespace: Optional[str]
     try:
         namespace = get_from_subsection(CONFIG, "remotes", remote, "SG_NAMESPACE")
     except KeyError:
