@@ -59,6 +59,8 @@ if TYPE_CHECKING:
     # the connection property otherwise
     from psycopg2._psycopg import connection as Connection
 
+psycopg2.extensions.register_adapter(dict, Json)
+
 _AUDIT_SCHEMA = "splitgraph_audit"
 _AUDIT_TRIGGER = "resources/static/audit_trigger.sql"
 _PUSH_PULL = "resources/static/splitgraph_api.sql"
@@ -181,13 +183,19 @@ def chunk(sequence: Sequence[T], chunk_size: int = API_MAX_VARIADIC_ARGS) -> Ite
         yield curr_chunk
 
 
-def get_conn_str(conn_params: Dict[str, str]) -> str:
+def _get(d: Dict[str, Optional[str]], k: str) -> str:
+    result = d.get(k)
+    assert result
+    return result
+
+
+def get_conn_str(conn_params: Dict[str, Optional[str]]) -> str:
     server, port, username, password, dbname = (
-        conn_params["SG_ENGINE_HOST"],
-        conn_params["SG_ENGINE_PORT"],
-        conn_params["SG_ENGINE_USER"],
-        conn_params["SG_ENGINE_PWD"],
-        conn_params["SG_ENGINE_DB_NAME"],
+        _get(conn_params, "SG_ENGINE_HOST"),
+        _get(conn_params, "SG_ENGINE_PORT"),
+        _get(conn_params, "SG_ENGINE_USER"),
+        _get(conn_params, "SG_ENGINE_PWD"),
+        _get(conn_params, "SG_ENGINE_DB_NAME"),
     )
     return f"postgresql://{username}:{password}@{server}:{port}/{dbname}"
 
@@ -214,10 +222,6 @@ class PsycopgEngine(SQLEngine):
         """
         super().__init__()
 
-        # Allow users to send SIGINT to quickly terminate sgr (instead of waiting for a PG
-        # statement to finish)
-        psycopg2.extensions.set_wait_callback(psycopg2.extras.wait_select)
-
         if not conn_params and not pool:
             raise ValueError("One of conn_params/pool must be specified!")
 
@@ -509,7 +513,7 @@ class PsycopgEngine(SQLEngine):
             with connection.cursor(**cursor_kwargs) as cur:
                 try:
                     self.notices = []
-                    cur.execute(statement, _convert_vals(arguments) if arguments else None)
+                    cur.execute(statement, arguments)
                     if connection.notices:
                         self.notices = connection.notices[:]
                         del connection.notices[:]
@@ -601,7 +605,7 @@ class PsycopgEngine(SQLEngine):
                 batches = _paginate_by_size(
                     cur,
                     statement,
-                    (_convert_vals(a) for a in arguments),
+                    arguments,
                     max_size=API_MAX_QUERY_LENGTH,
                 )
                 for batch in batches:
@@ -749,6 +753,7 @@ class PsycopgEngine(SQLEngine):
                     cur.execute("SELECT 1 FROM pg_database WHERE datname = %s", (pg_db,))
                     if cur.fetchone() is None:
                         logging.info("Creating database %s", pg_db)
+                        cur.execute("ROLLBACK")
                         cur.execute(SQL("CREATE DATABASE {}").format(Identifier(pg_db)))
                     else:
                         logging.info("Database %s already exists, skipping", pg_db)
@@ -790,6 +795,8 @@ class PsycopgEngine(SQLEngine):
         with self._admin_conn() as admin_conn:
             admin_conn.autocommit = True
             with admin_conn.cursor() as cur:
+                # For some reason without it we get "DROP DATABASE cannot run inside a transaction block"
+                cur.execute("ROLLBACK")
                 cur.execute(SQL("DROP DATABASE IF EXISTS {}").format(Identifier(database)))
 
 
@@ -1316,7 +1323,7 @@ class PostgresEngine(AuditTriggerChangeEngine, ObjectEngine):
         target_schema: str,
         target_table: str,
         extra_quals: Optional[Composed] = None,
-        extra_qual_args: Optional[Tuple[str]] = None,
+        extra_qual_args: Optional[Tuple[Any, ...]] = None,
         schema_spec: Optional["TableSchema"] = None,
         progress_every: Optional[int] = None,
     ) -> None:
@@ -1598,13 +1605,6 @@ def _convert_audit_change(
 _KIND = {"I": 0, "D": 1, "U": 2}
 
 
-def _convert_vals(vals: Any) -> Any:
-    """Psycopg returns jsonb objects as dicts/lists but doesn't actually accept them directly
-    as a query param (or in the case of lists coerces them into an array.
-    Hence, we have to wrap them in the Json datatype when doing a dump + load."""
-    return [Json(v) if isinstance(v, dict) else v for v in vals]
-
-
 def _generate_where_clause(table: str, cols: List[str], table_2: str) -> Composed:
     return SQL(" AND ").join(
         SQL("{}.{} = {}.{}").format(
