@@ -1,12 +1,12 @@
+from copy import deepcopy
+
 import json
 import logging
+import psycopg2
 import re
 from abc import ABC, abstractmethod
-from copy import deepcopy
-from typing import Optional, Mapping, Dict, List, Any, cast, TYPE_CHECKING, Tuple
-
-import psycopg2
 from psycopg2.sql import SQL, Identifier
+from typing import Optional, Mapping, Dict, List, Any, cast, TYPE_CHECKING, Tuple
 
 from splitgraph.core.types import (
     TableSchema,
@@ -17,8 +17,9 @@ from splitgraph.core.types import (
     PreviewResult,
     MountError,
     IntrospectionResult,
+    Credentials,
 )
-from splitgraph.exceptions import get_exception_name
+from splitgraph.exceptions import get_exception_name, DataSourceError
 from splitgraph.hooks.data_source.base import (
     MountableDataSource,
     LoadableDataSource,
@@ -50,6 +51,8 @@ class ForeignDataWrapperDataSource(MountableDataSource, LoadableDataSource, ABC)
     @classmethod
     def from_commandline(cls, engine, commandline_kwargs) -> "ForeignDataWrapperDataSource":
         """Instantiate an FDW data source from commandline arguments."""
+        from splitgraph.cloud.models import ExternalTableRequest
+
         # Normally these are supposed to be more user-friendly and FDW-specific (e.g.
         # not forcing the user to pass in a JSON with five levels of nesting etc).
         params = deepcopy(commandline_kwargs)
@@ -59,10 +62,12 @@ class ForeignDataWrapperDataSource(MountableDataSource, LoadableDataSource, ABC)
         #   * A dictionary table_name -> {"schema": schema, "options": table options}
         tables = params.pop("tables", None)
         if isinstance(tables, dict):
-            tables = dict_to_table_schema_params(tables)
+            tables = dict_to_table_schema_params(
+                {k: ExternalTableRequest.parse_obj(v) for k, v in tables.items()}
+            )
 
         # Extract credentials from the cmdline params
-        credentials: Dict[str, Any] = {}
+        credentials = Credentials({})
         for k in cast(Dict[str, Any], cls.credentials_schema["properties"]).keys():
             if k in params:
                 credentials[k] = params[k]
@@ -110,6 +115,7 @@ class ForeignDataWrapperDataSource(MountableDataSource, LoadableDataSource, ABC)
         tables: Optional[TableInfo] = None,
         overwrite: bool = True,
     ) -> Optional[List[MountError]]:
+        self._validate_table_params(tables)
         tables = tables or self.tables or []
 
         fdw = self.get_fdw_name()
@@ -175,13 +181,15 @@ class ForeignDataWrapperDataSource(MountableDataSource, LoadableDataSource, ABC)
             for v in table_options.values():
                 jsonschema.validate(v, self.table_params_schema)
 
-            result: IntrospectionResult = {
-                t: (
-                    self.engine.get_full_table_schema(tmp_schema, t),
-                    cast(TableParams, table_options.get(t, {})),
-                )
-                for t in self.engine.get_all_tables(tmp_schema)
-            }
+            result = IntrospectionResult(
+                {
+                    t: (
+                        self.engine.get_full_table_schema(tmp_schema, t),
+                        cast(TableParams, table_options.get(t, {})),
+                    )
+                    for t in self.engine.get_all_tables(tmp_schema)
+                }
+            )
 
             # Add errors to the result as well
             for error in mount_errors:
@@ -245,9 +253,9 @@ class ForeignDataWrapperDataSource(MountableDataSource, LoadableDataSource, ABC)
         tmp_schema = get_temporary_table_id()
         try:
             # Seed the result with the tables that failed to mount
-            result: PreviewResult = {
-                e.table_name: e for e in self.mount(tmp_schema, tables=tables) or []
-            }
+            result = PreviewResult(
+                {e.table_name: e for e in self.mount(tmp_schema, tables=tables) or []}
+            )
 
             # Commit so that errors don't cancel the mount
             self.engine.commit()
@@ -272,7 +280,10 @@ class ForeignDataWrapperDataSource(MountableDataSource, LoadableDataSource, ABC)
 
         tmp_schema = get_temporary_table_id()
         try:
-            self.mount(tmp_schema, tables=tables)
+            errors = self.mount(tmp_schema, tables=tables)
+            if errors:
+                raise DataSourceError("Error mounting tables for load")
+
             self.engine.commit()
 
             for t in self.engine.get_all_tables(tmp_schema):
