@@ -1,10 +1,11 @@
 import json
 from copy import deepcopy
+from datetime import timedelta
 from typing import Optional, TYPE_CHECKING, Dict, List, Tuple, Any
 
 from psycopg2.sql import SQL, Identifier
 
-from splitgraph.core.types import TableInfo, MountError
+from splitgraph.core.types import TableInfo, MountError, Credentials
 from splitgraph.hooks.data_source.fdw import ForeignDataWrapperDataSource, import_foreign_schema
 from splitgraph.ingestion.common import IngestionAdapter, build_commandline_help
 
@@ -67,12 +68,12 @@ def query_to_csv(engine: "PsycopgEngine", query, buffer, schema: Optional[str] =
 
 
 class CSVDataSource(ForeignDataWrapperDataSource):
-    credentials_schema = {
+    credentials_schema: Dict[str, Any] = {
         "type": "object",
         "properties": {"s3_access_key": {"type": "string"}, "s3_secret_key": {"type": "string"}},
     }
 
-    params_schema = {
+    params_schema: Dict[str, Any] = {
         "type": "object",
         "properties": {
             "url": {"type": "string", "description": "HTTP URL to the CSV file"},
@@ -123,7 +124,7 @@ class CSVDataSource(ForeignDataWrapperDataSource):
         "oneOf": [{"required": ["url"]}, {"required": ["s3_endpoint", "s3_bucket"]}],
     }
 
-    table_params_schema = {
+    table_params_schema: Dict[str, Any] = {
         "type": "object",
         "properties": {
             "url": {"type": "string", "description": "HTTP URL to the CSV file"},
@@ -178,7 +179,7 @@ EOF
     @classmethod
     def from_commandline(cls, engine, commandline_kwargs) -> "CSVDataSource":
         params = deepcopy(commandline_kwargs)
-        credentials = {}
+        credentials = Credentials({})
         for k in ["s3_access_key", "s3_secret_key"]:
             if k in params:
                 credentials[k] = params[k]
@@ -265,3 +266,44 @@ EOF
     def get_remote_schema_name(self) -> str:
         # We ignore the schema name and use the bucket/prefix passed in the params instead.
         return "data"
+
+    @staticmethod
+    def _get_url(merged_options: Dict[str, Any], expiry: int = 3600) -> List[Tuple[str, str]]:
+        from splitgraph.ingestion.csv.common import get_s3_params
+
+        if merged_options.get("url"):
+            # Currently all URLs are public anyway, so return it directly
+            return [("text/csv", merged_options["url"])]
+        else:
+            # Instantiate the Minio client and pre-sign a URL
+            s3_client, s3_bucket, s3_object_prefix = get_s3_params(merged_options)
+            s3_object = merged_options.get("s3_object")
+            if not s3_object:
+                return []
+            return [
+                (
+                    "text/csv",
+                    s3_client.presigned_get_object(
+                        bucket_name=s3_bucket,
+                        object_name=s3_object,
+                        expires=timedelta(seconds=expiry),
+                    ),
+                )
+            ]
+
+    def get_raw_url(
+        self, tables: Optional[TableInfo] = None, expiry: int = 3600
+    ) -> Dict[str, List[Tuple[str, str]]]:
+        tables = tables or self.tables
+        if not tables:
+            return {}
+        result: Dict[str, List[Tuple[str, str]]] = {}
+
+        # Merge the table options to take care of overrides and use them to get URLs
+        # for each table.
+        for table in tables:
+            table_options = super().get_table_options(table, tables)
+            full_options = {**self.credentials, **self.params, **table_options}
+            result[table] = self._get_url(full_options)
+
+        return result
