@@ -2,11 +2,11 @@
 import json
 import logging
 from copy import deepcopy
-from typing import Optional, Dict, List
+from typing import Optional, Dict, List, Tuple
 
 from psycopg2.sql import SQL, Identifier
 
-from splitgraph.core.types import TableInfo, MountError
+from splitgraph.core.types import TableInfo, MountError, Credentials
 from splitgraph.exceptions import RepositoryNotFoundError
 from splitgraph.hooks.data_source.fdw import create_foreign_table, ForeignDataWrapperDataSource
 
@@ -67,7 +67,7 @@ class SocrataDataSource(ForeignDataWrapperDataSource):
         if isinstance(tables, dict) and isinstance(next(iter(tables.values())), str):
             tables = {k: ([], {"socrata_id": v}) for k, v in tables.items()}
 
-        credentials = {"app_token": params.pop("app_token", None)}
+        credentials = Credentials({"app_token": params.pop("app_token", None)})
         return cls(engine, credentials, params, tables)
 
     def get_server_options(self):
@@ -116,6 +116,31 @@ class SocrataDataSource(ForeignDataWrapperDataSource):
         self.engine.run_sql(SQL(";").join(mount_statements), mount_args)
         return []
 
+    def get_raw_url(
+        self, tables: Optional[TableInfo] = None, expiry: int = 3600
+    ) -> Dict[str, List[Tuple[str, str]]]:
+        tables = tables or self.tables
+        if not tables:
+            return {}
+        result: Dict[str, List[Tuple[str, str]]] = {}
+
+        for table in tables:
+            table_options = super().get_table_options(table, tables)
+            full_options = {**self.params, **table_options}
+            domain = full_options.get("domain")
+            socrata_id = full_options.get("socrata_id")
+            if not domain or not socrata_id:
+                continue
+
+            result[table] = [
+                (
+                    "text/csv",
+                    f"https://{domain}/api/views/{socrata_id}/rows.csv?accessType=DOWNLOAD",
+                )
+            ]
+
+        return result
+
 
 def generate_socrata_mount_queries(sought_ids, datasets, mountpoint, server_id, tables: TableInfo):
     # Local imports since this module gets run from commandline entrypoint on startup.
